# fastly terraformサンプル

## ディレクトリ構成

```
.
├── bin
│   └── terraform
├── modules
│   └── sample
│       └── fastly
│           ├── fastly.tf
│           └── vcl
│               └── default.vcl
├── README.md
└── services
    └── sample
        ├── dev
        │   └── cdn-dev.example.net
        │       ├── fastly.tf
        │       └── terraform -> ../../../../bin/terraform
        └── prod
            └── cdn.example.net
                ├── fastly.tf
                └── terraform -> ../../../../bin/terraform

```

## 使い方

terraformの[公式サイト](https://www.terraform.io/downloads.html)からterraformのバイナリを取得して

> bin/terraform

に配置する。

そのあとfastlyの管理画面よりAPIキーを発行して

> export FASTLY_API_KEY="発行したAPIキー"

を行う。

services以下のfastly.tfの配信ドメインとオリジンの設定を適切に編集した後に同ディレクトリで

> ./terraform init
> ./terraform apply

することで設定の展開ができます。

なお、カスタムVCL(modules/sample/fastly/vcl/default.vcl)には6章で入れた

- デフォルトはキャッシュをしない
- /static/はキャッシュをする
- /cache/はcookieを消したうえでキャッシュをする

の設定が入っています。
あくまでサンプルのため、実際に作る際はこのvclは使わずは必ず[公式](https://docs.fastly.com/vcl/custom-vcl/creating-custom-vcl/)から取得して使用してください。

## 設定の思想

fastlyはステージング環境というものがなく、事前に設定のチェックをするためには別のサービスを作る必要があるため、
構造としてドメインなどの設定を記載するservices以下とドメインに依存しない設定を記載するmodules以下に分けています。
これによりmodules以下を変更して設定を修正した際に先にdev環境でapplyしてテストののちprodで展開するといったことが可能です。


他の使い方として、筆者は静的配信用の基本的な設定をmodules以下に作って、services以下に複数サービスを量産するといったこともしています。

あくまでこの設定は簡易なもので、いろいろカスタマイズして使ってみてください
